@@ -11,7 +11,7 @@ from enum import Enum
 from typing import Callable
 
 from mbed_tools.targets.env import env
-from mbed_tools.targets.exceptions import UnknownBoard, UnsupportedMode
+from mbed_tools.targets.exceptions import UnknownBoard, UnsupportedMode, BoardDatabaseError
 from mbed_tools.targets.board import Board
 from mbed_tools.targets.boards import Boards
 
@@ -45,6 +45,25 @@ def get_board_by_online_id(slug: str, target_type: str) -> Board:
     return get_board(lambda board: board.slug.casefold() == matched_slug and board.target_type == target_type)
 
 
+def get_board_by_jlink_slug(slug: str) -> Board:
+    """Returns first `mbed-tools.targets.board.Board` matching given slug.
+
+    With J-Link, the slug is extracted from a board manufacturer URL, and may not match
+    the Mbed slug. The J-Link slug is compared against the slug, board_name and
+    board_type of entries in the board database until a match is found.
+
+    Args:
+        slug: the J-Link slug to look up in the database.
+
+    Raises:
+        UnknownBoard: a board matching the slug was not found.
+    """
+    matched_slug = slug.casefold()
+    return get_board(
+        lambda board: any(matched_slug == c.casefold() for c in [board.slug, board.board_name, board.board_type])
+    )
+
+
 def get_board(matching: Callable) -> Board:
     """Returns first `mbed_tools.targets.board.Board` for which `matching` is True.
 
@@ -70,7 +89,11 @@ def get_board(matching: Callable) -> Board:
         return Boards.from_offline_database().get_board(matching)
     except UnknownBoard:
         logger.info("Unable to identify a board using the offline database, trying the online database.")
-        return Boards.from_online_database().get_board(matching)
+        try:
+            return Boards.from_online_database().get_board(matching)
+        except BoardDatabaseError:
+            logger.error("Unable to access the online database to identify a board.")
+            raise UnknownBoard()
 
 
 class _DatabaseMode(Enum):
